#ifndef XINEMACONTROL_H_
#define XINEMACONTROL_H_

#include <QObject>
#include <QTcpSocket>

class XinemaControl: public QObject
{
	Q_OBJECT

private:
	QTcpSocket socket;
	QByteArray buffer;
	QString title;
	float duration;
	float position;

public:
	XinemaControl();

	void connect(const QHostAddress &);
	bool is_connected() const;

	void list_directory(const QString &);
	void play_file(const QString &);

	const QString &get_title() const { return title; }
	float get_duration() const { return duration; }
	float get_position() const { return position; }

signals:
	void connected();
	void disconnected();
	void directory_started(const QString &);
	void file_added(const QString &);
	void subdirectory_added(const QString &);
	void title_changed(const QString &);
	void duration_changed(float);
	void position_changed(float);

private:
	void send_request(const QString &);

private slots:
	void data_available();
	void process_reply(const QString &);
};

#endif
